"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.imageFromId = imageFromId;
exports.makeSrcset = makeSrcset;
exports.defaultSteps = void 0;

var _config = require("../../config");

/* eslint-disable camelcase */
var missingCloudError = new Error('Please provide cloud as image props, or use getCloudinaryUsername from config');
var defaultSteps = [{
  vw: 400,
  w: 400
}, {
  vw: 600,
  w: 600
}, {
  vw: 800,
  w: 800
}, {
  vw: 1000,
  w: 1000
}, {
  vw: 1200,
  w: 1200
}];
exports.defaultSteps = defaultSteps;

function imageFromId(_ref) {
  var _cloud = _ref.cloud,
      transform = _ref.transform,
      public_id = _ref.public_id;

  var cloud = _cloud || (0, _config.getCloudinaryUsername)();

  if (!cloud) {
    throw missingCloudError;
  }

  return ['//res.cloudinary.com', cloud || (0, _config.getCloudinaryUsername)(), 'image/upload', transform, public_id].filter(function (x) {
    return x;
  }).join('/');
}

function makeSrcset(_ref2) {
  var _cloud = _ref2.cloud,
      transform = _ref2.transform,
      public_id = _ref2.public_id,
      _ref2$steps = _ref2.steps,
      steps = _ref2$steps === void 0 ? defaultSteps : _ref2$steps;

  var cloud = _cloud || (0, _config.getCloudinaryUsername)();

  if (!cloud) {
    throw missingCloudError;
  }

  return steps.map(function (_ref3) {
    var vw = _ref3.vw,
        w = _ref3.w;
    var size = vw;
    var src = ['//res.cloudinary.com', cloud, 'image/upload', ["w_".concat(w), transform].filter(function (x) {
      return x;
    }).join(','), public_id].join('/');
    return {
      src: src,
      size: size
    };
  });
}