// @flow

import React from 'react'
import cn from 'classnames'
import Icon from 'components/Icon'

const Item = ({
  theme,
  icon,
  label,
  values,
}: {
  theme: TTheme,
  icon: string,
  label: string,
  values: string[],
}) => (
  <div className={theme.itemWrapper}>
    <div className={theme.labelWrapper}>
      {icon && <Icon icon={icon} className={theme.icon} />}
      {label && <span className={theme.label}>{label}</span>}
    </div>
    <div className={theme.valueWrapper}>
      {values.filter(x => x).map((value, idx) => (
        <div key={idx} className={theme.value}>
          {value}
        </div>
      ))}
    </div>
  </div>
)

function ContactInfo(props: {
  className?: string,
  address: any,
  phone: any,
  email: any,
  icons?: { [key: string]: string },
  labels?: { [key: string]: string },
  theme?: TTheme,
}) {
  const {
    className,
    address: _address,
    phone: _phone,
    email: _email,
    icons = {},
    labels = {},
    theme = {},
    ...rest
  } = props
  if (!_address && !_phone && !_email) return null
  const address: string[] = Array.isArray(_address) ? _address : [_address]
  const phone: string[] = Array.isArray(_phone) ? _phone : [_phone]
  const email: string[] = Array.isArray(_email) ? _email : [_email]
  const list = { address, phone, email }
  const keys = Object.keys(list)
  return (
    <div
      {...rest}
      data-component="ContactInfo"
      className={cn(theme.root, className)}
    >
      {keys.map((key) => {
        const icon = icons[key]
        const label = labels[key]
        const values = list[key]
        return (
          <Item
            key={key}
            icon={icon}
            label={label}
            values={values}
            theme={theme}
          />
        )
      })}
    </div>
  )
}

export default ContactInfo
