// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import { compose } from 'recompose'
import { connect } from 'react-redux'
import dopProp from 'dot-prop-immutable'
import { Motion, spring } from 'react-motion'

function Drawer({
  isOpened,
  children,
  dispatch, // eslint-disable-line
  ...rest
}: {
  isOpened: boolean,
  children: any,
  theme: TTheme,
}) {
  return (
    <Motion defaultStyle={{ x: -100 }} style={{ x: spring(isOpened ? 0 : -100) }}>
      {({ x }) => (
        <div
          {...rest}
          style={{
            transform: `translateY(${x}vh)`,
          }}
        >
          {children}
        </div>
      )}
    </Motion>
  )
}

export default compose(
  connect((state, { name }) => {
    const isOpened = dopProp.get(state, ['app', 'drawer', name])
    return {
      isOpened,
    }
  }),
  themr('Drawer', {}, { composeTheme: 'softly' }),
)(Drawer)
