/* eslint-disable camelcase */

// @flow

import { setCloudinaryUsername } from '../../../config'
import { imageFromId, makeSrcset } from '../cloudinary'

const cloud = 'default_cloud'
const public_id = 'my-image.jpg'

const expectedDefaultSrcset = [
  {
    size: 400,
    src: '//res.cloudinary.com/default_cloud/image/upload/w_400/my-image.jpg',
  },
  {
    size: 600,
    src: '//res.cloudinary.com/default_cloud/image/upload/w_600/my-image.jpg',
  },
  {
    size: 800,
    src: '//res.cloudinary.com/default_cloud/image/upload/w_800/my-image.jpg',
  },
  {
    size: 1000,
    src: '//res.cloudinary.com/default_cloud/image/upload/w_1000/my-image.jpg',
  },
  {
    size: 1200,
    src: '//res.cloudinary.com/default_cloud/image/upload/w_1200/my-image.jpg',
  },
]

describe('make cloudinary url', () => {
  setCloudinaryUsername(cloud)

  it('make image from public_id', () => {
    const result = imageFromId({ public_id })
    expect(result).toEqual(
      '//res.cloudinary.com/default_cloud/image/upload/my-image.jpg',
    )
  })

  it('make image from public_id, with transform', () => {
    const result = imageFromId({
      public_id,
      transform: 'q_80,w_500',
    })
    expect(result).toEqual(
      '//res.cloudinary.com/default_cloud/image/upload/q_80,w_500/my-image.jpg',
    )
  })

  it('make image from public_id, with custom cloud', () => {
    const result = imageFromId({
      public_id,
      cloud: 'another_cloud',
    })
    expect(result).toEqual(
      '//res.cloudinary.com/another_cloud/image/upload/my-image.jpg',
    )
  })

  it('make image from public_id, with transform & custom cloud', () => {
    const result = imageFromId({
      public_id,
      cloud: 'another_cloud',
      transform: 'q_80,w_500',
    })
    expect(result).toEqual(
      '//res.cloudinary.com/another_cloud/image/upload/q_80,w_500/my-image.jpg',
    )
  })
})

describe('make srcset', () => {
  it('default steps', () => {
    const result = makeSrcset({ public_id })
    expect(result).toEqual(expectedDefaultSrcset)
  })

  it('custom steps', () => {
    const result = makeSrcset({ public_id, steps: [{ w: 500, vw: 500 }] })
    expect(result).toEqual([
      {
        size: 500,
        src:
          '//res.cloudinary.com/default_cloud/image/upload/w_500/my-image.jpg',
      },
    ])
  })

  it('custom steps & cloud', () => {
    const result = makeSrcset({
      public_id,
      cloud: 'another_cloud',
      steps: [{ w: 500, vw: 500 }],
    })
    expect(result).toEqual([
      {
        size: 500,
        src:
          '//res.cloudinary.com/another_cloud/image/upload/w_500/my-image.jpg',
      },
    ])
  })
})
