/* eslint-disable camelcase */

// @flow

import { getCloudinaryUsername } from 'config'

const missingCloudError = new Error('Please provide cloud as image props, or use getCloudinaryUsername from config')

export const defaultSteps = [
  { vw: 400, w: 400 },
  { vw: 600, w: 600 },
  { vw: 800, w: 800 },
  { vw: 1000, w: 1000 },
  { vw: 1200, w: 1200 },
]

export function imageFromId({
  cloud: _cloud,
  transform,
  public_id,
}: {
  cloud?: string,
  transform?: string,
  public_id: string,
}) {
  const cloud = _cloud || getCloudinaryUsername()
  if (!cloud) {
    throw missingCloudError
  }
  return [
    '//res.cloudinary.com',
    cloud || getCloudinaryUsername(),
    'image/upload',
    transform,
    public_id,
  ].filter(x => x).join('/')
}

export function makeSrcset({
  cloud: _cloud,
  transform,
  public_id,
  steps = defaultSteps,
}: {
  cloud?: string,
  transform?: string,
  public_id: string,
  steps?: { vw: number, w: number }[],
}) {
  const cloud = _cloud || getCloudinaryUsername()
  if (!cloud) {
    throw missingCloudError
  }
  return steps.map(({ vw, w }) => {
    const size = vw
    const src = [
      '//res.cloudinary.com',
      cloud,
      'image/upload',
      [`w_${w}`, transform].filter(x => x).join(','),
      public_id,
    ].join('/')
    return { src, size }
  })
}
