// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import Image, { type ImageProps } from 'components/Image'
import omit from 'lodash.omit'
import Background from 'components/Background'
import InfoItem, { type InfoItemProps } from 'components/InfoItem'

export type Props = {
  image?: ImageProps,
  asBackground?: boolean,
  info: InfoItemProps,
  theme?: *,
}

function ImageItem({ image, asBackground, info, theme = {}, ...props }: Props) {
  return (
    <div {...props} data-component="ImageItem" className={theme.root}>
      {image &&
        !asBackground && (
          <div className={theme.imageWrapper}>
            <Image className={theme.image} {...image} />
          </div>
        )}
      {image &&
        asBackground && (
          <div className={theme.imageWrapper}>
            <Background
              className={theme.image}
              {...omit(image, ['steps'])}
            />
          </div>
        )}
      <div className={theme.infoWrapper}>
        <InfoItem theme={theme.info} {...info} />
      </div>
    </div>
  )
}

export default themr('ImageItem', {}, { composeTheme: 'softly' })(ImageItem)
