// @flow

import React from 'react'
import { connect, Provider } from 'react-redux'
import Modal from 'react-modal'
import { createStore } from 'redux'
import _Link from '../..'

const Link = connect()(_Link)

Modal.setAppElement('#root')

function reducer(state = {}, action) {
  switch (action.type) {
    case 'open-modal':
      return {
        ...state,
        modal: action.payload,
      }
    case 'close-modal':
      return {
        ...state,
        modal: undefined,
      }
    default:
      return state
  }
}

const MyModal = connect(state => state)((props) => {
  const { modal, dispatch } = props
  return (
    <Modal
      onRequestClose={() => dispatch({ type: 'close-modal' })}
      isOpen={modal === props.name}
    >
      This is {props.name}
    </Modal>
  )
})

const store = createStore(reducer)

const modals = ['modal 01', 'modal 02']
const LinkComponent = () => modals.map(name => (
  <Link
    key={name}
    className="mr2 pa2 ba b--light-gray dib pointer"
    action={{ type: 'open-modal', payload: name }}
  >
      Open {name}
  </Link>
))

function ActionLinkExample() {
  return (
    <Provider store={store}>
      <div>
        <LinkComponent />
        {modals.map(name => <MyModal key={name} name={name} />)}
      </div>
    </Provider>
  )
}

export default ActionLinkExample
