// @flow

import React from 'react'
import cn from 'classnames'
import dopProp from 'dot-prop-immutable'
import { compose } from 'recompose'
import { connect } from 'react-redux'
import { themr } from 'react-css-themr'
import Icon from 'components/Icon'

type Props = {
  isOpened: boolean, // From Redux
  className?: string,
  dispatch: Function,
  openIcon: string,
  openText: string,
  closeIcon: string,
  closeText: string,
  name: string, // Path to toggle
  type: 'modal' | 'drawer' | 'if',
  theme: *,
}

function ToggleButton({
  isOpened,
  className,
  dispatch,
  openIcon,
  openText,
  closeIcon,
  closeText,
  name,
  type,
  theme,
  ...rest
}: Props) {
  return (
    <div
      {...rest}
      className={cn(theme.root, className)}
      onClick={() => dispatch({ type: `toggle-${type}`, payload: name })}
    >
      {isOpened ? (
        <Icon className={theme.icon} icon={closeIcon} />
      ) : (
        <Icon className={theme.icon} icon={openIcon} />
      )}
      <span className={theme.text}>{isOpened ? closeText : openText}</span>
    </div>
  )
}

export default compose(
  themr('ToggleButton', {}, { composeTheme: 'softly' }),
  connect((state, { name, type }) => {
    const isOpened = dopProp.get(state, ['app', type, name])
    return { isOpened }
  }),
)(ToggleButton)
