// @flow

import React, { PureComponent } from 'react'
import cn from 'classnames'
import { getYoutubeVideos } from 'helpers/getVideos'

const regExp = /src="https:\/\/www.youtube.com\/embed\/(.*?)\?feature=oembed"/

type Props = {
  items: string[],
  theme?: TTheme,
}

class VideoPlayList extends PureComponent<Props, any> {
  state = {
    selected: 0,
    videos: [],
  }
  loadEmbed = (items: string[]) => {
    const promises = items.map(video => getYoutubeVideos(video))

    Promise.all(promises).then((_videos) => {
      const videos = _videos.filter(x => !!x).map(({ html, ...rest }) => {
        const tmp = regExp.exec(html)
        const id = tmp && tmp[1]
        return {
          ...rest,
          id,
        }
      })
      this.setState({ videos })
    })
  }
  componentDidMount() {
    const { items } = this.props
    if (items) this.loadEmbed(items)
  }
  renderListItem = (item: any, idx: number) => {
    const { theme = {} } = this.props
    const { title, author_name: author, thumbnail_url: thumb } = item || {}
    return (
      <div
        key={idx}
        className={theme.itemWrapper}
        onClick={() => this.setState({ selected: idx })}
      >
        <div className={theme.imageWrapper}>
          <div
            className={theme.image}
            style={{ backgroundImage: `url(${thumb})` }}
            alt={title}
          />
        </div>
        <div className={theme.info}>
          <div className={theme.titleWrapper}>
            <span className={theme.title}>{title}</span>
          </div>
          <div className={theme.authorWrapper}>
            <span className={theme.author}>{author}</span>
          </div>
        </div>
      </div>
    )
  }
  addClassIframe = (iframe: string, className: string) =>
    (iframe && iframe.replace(/src=/i, `class="${className}" src=`)) || null
  render() {
    const { theme = {} } = this.props
    const { selected, videos = [] } = this.state
    const video = (videos && videos[selected]) || {}
    return (
      <div className={theme.root}>
        <div className={theme.content}>
          <div className={cn('relative', theme.iframe)}>
            <div className="absolute absolute--fill">
              <iframe
                width="100%"
                height="100%"
                src={`https://www.youtube.com/embed/${video.id}`}
                frameBorder={0}
              />
            </div>
          </div>
        </div>
        <div className={cn('overflow-y-scroll relative', theme.listWrapper)}>
          <div className={cn('absolute absolute--fill', theme.list)}>
            {videos.map((item, idx) => this.renderListItem(item, idx))}
          </div>
        </div>
      </div>
    )
  }
}

export default VideoPlayList
