import getImageLink from '../getImageLink'

const username = 'nhavungtau'
const id = 'guagv33k6vxfvm8balwg'

describe('get image link', () => {
  it('use src', () => {
    const result = 'https://source.unsplash.com/random/800x600'
    const src = 'https://source.unsplash.com/random/800x600'
    const imageLink = getImageLink({
      src,
    })
    expect(imageLink).toEqual(result)
  })

  it('use src - cloudinary', () => {
    const result = {
      large:
        'https://res.cloudinary.com/nhavungtau/image/upload/guagv33k6vxfvm8balwg',
      thumbnail:
        'https://res.cloudinary.com/nhavungtau/image/upload/c_scale,q_auto,w_50/guagv33k6vxfvm8balwg',
    }
    const src =
      'https://res.cloudinary.com/nhavungtau/image/upload/c_scale,q_auto,w_400/guagv33k6vxfvm8balwg'
    const imageLink = getImageLink({
      src,
    })
    expect(imageLink).toEqual(result)
  })

  it('use cloudinary without auto scale', () => {
    const result = {
      large:
        'https://res.cloudinary.com/nhavungtau/image/upload/guagv33k6vxfvm8balwg',
      thumbnail:
        'https://res.cloudinary.com/nhavungtau/image/upload/guagv33k6vxfvm8balwg',
    }
    const imageLink = getImageLink({
      cloudinary: { username, id },
      autoScale: false,
    })
    expect(imageLink).toEqual(result)
  })

  it('use cloudinary with auto scale', () => {
    const result = {
      large:
        'https://res.cloudinary.com/nhavungtau/image/upload/c_scale,q_auto,h_400/guagv33k6vxfvm8balwg',
      thumbnail:
        'https://res.cloudinary.com/nhavungtau/image/upload/c_scale,q_auto,w_50/guagv33k6vxfvm8balwg',
    }
    const imageLink = getImageLink({
      cloudinary: { username, id },
      boxSize: { width: 239, height: 240 },
    })
    expect(imageLink).toEqual(result)
  })

  it('usePlaceholder = true', () => {
    const imageLink = getImageLink({
      boxSize: { width: 239, height: 240 },
      usePlaceholder: true,
    })
    expect(imageLink).toEqual('http://via.placeholder.com/239x240')
  })

  it('usePlaceholder = false', () => {
    const imageLink = getImageLink({
      boxSize: { width: 239, height: 240 },
      usePlaceholder: false,
    })
    expect(imageLink).toEqual('')
  })
})
